@@ -128,8 +128,8 @@ class MultiTaskLearner(object):
 
                 num_rows = self._get_num_rows(x)
 
-                if x[next(iter(x))].shape[0] == 1:
-                    # skipping batch size of 1
+                if num_rows == 1:
+                    # skip batches of size 1
                     continue
 
                 output = self.model(x)
